ExportHelper class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

exportCsv({required List<int> bytes, String fileName = 'Report.csv'}) Future<void>
CSV
exportExcel({required List<int> bytes, String fileName = 'Report.xlsx'}) Future<void>
Excel
exportFile({required List<int> bytes, required String fileName, bool openAfterDownload = true}) Future<void>
Generic Export Method
exportImage({required List<int> bytes, String fileName = 'Image.png'}) Future<void>
Image
exportJson({required List<int> bytes, String fileName = 'Report.json'}) Future<void>
JSON
exportPdf({required List<int> bytes, String fileName = 'Report.pdf'}) Future<void>
PDF
exportText({required List<int> bytes, String fileName = 'Report.txt'}) Future<void>
Text
exportWord({required List<int> bytes, String fileName = 'Report.docx'}) Future<void>
Word
exportZip({required List<int> bytes, String fileName = 'Report.zip'}) Future<void>
ZIP