SizeConfig class

Constructors

SizeConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

effectiveHeight double
no setter
effectiveWidth double
no setter
isDesktop bool
no setter
isMobile bool
no setter
isTablet bool
no setter
screenHeight double
getter/setter pair
screenWidth double
getter/setter pair

Static Methods

fontSize(double size) double
h(double height) double
hp(double percent) double
icon(double value) double
init(BuildContext context) → void
p(double value) double
r(double value) double
w(double width) double
wp(double percent) double

Constants

baseHeight → const double
baseWidth → const double