AppColors class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- backgroundDark → const Color
- backgroundLight → const Color
- brand50 → const Color
- brand100 → const Color
- brand200 → const Color
- brand300 → const Color
- brand400 → const Color
- brand500 → const Color
- brand600 → const Color
- brand700 → const Color
- brand800 → const Color
- brand900 → const Color
- brand950 → const Color
- brandMaterial → const MaterialColor
- primary → const Color
- textPrimaryDark → const Color
- textPrimaryLight → const Color